# m3-django-compatibility

`m3-django-compatibility` - это библиотека для обеспечения совместимости кода с разными версиями Django. Использование 
инструментов библиотеки позволяет писать код, работающий без изменений в разных версиях Django.

Поддерживаемые версии Django: 1.4 - 2.2.
